<?php

/**
 * Plugin Name:       Multiple Customer Addresses
 * Plugin URI:        https://woocommerce.com/products/multiple-customer-addresses/
 * Description:       Allow customers to add multiple billing and shipping addresses.
 * Version:           1.3.1
 * Author:            KoalaApps
 * Developed By:      KoalaApps
 * Author URI:        https://woocommerce.com/vendor/koalaapps/
 * Support:           https://woocommerce.com/vendor/koalaapps/
 * Domain Path:       /languages
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * TextDomain : koala-multiple-customer-addresses
 * Woo: 8178490:d215bcf58e1aeee087bb4c0e26d5a064
 * WC requires at least: 3.0.9
 * WC tested up to: 9.*.*
 *
 * @package : Koala multiple customer addresses
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Define class.
 */
class Ka_Customer_Addresses {
	public function __construct() {
		$this->wmsa_global_constents_vars();
		add_action( 'wp_loaded', array( $this, 'accm_init' ) );

		// HOPS compatibility
				add_action( 'before_woocommerce_init', array( $this, 'kawmsa_HOPS_Compatibility' ) );

		if ( is_admin() ) {
			include_once WMSA_PLUGIN_DIR . 'includes/admin/class-koala-wmsa-admin.php';
			include_once WMSA_PLUGIN_DIR . 'includes/admin/class-koala-wsma-user-order.php';
		} else {
			include_once WMSA_PLUGIN_DIR . 'includes/class-koala-wmsa-front.php';
		}
		include_once WMSA_PLUGIN_DIR . 'includes/class-koala-wmsa-ajax.php';
		include_once WMSA_PLUGIN_DIR . 'includes/general-function.php';

		register_activation_hook(
			__FILE__,
			function () {
				update_option( 'address_title_tag_key_field', 'h3' );
			}
		);
		add_action( 'woocommerce_blocks_loaded', array( $this, 'kl_wmsa_block_init' ) );
	}

	public function kawmsa_HOPS_Compatibility() {

		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}

	public function wmsa_global_constents_vars() {
		if ( ! defined( 'KA_MULTIPLE_CUSTOMER_BLOCK_VERSION' ) ) {
			$ka_version = get_file_data( __FILE__, array( 'version' => 'version' ) );
			define( 'KA_MULTIPLE_CUSTOMER_BLOCK_VERSION', $ka_version['version'] );
		}
		if ( ! defined( 'WMSA_URL' ) ) {
			define( 'WMSA_URL', plugin_dir_url( __FILE__ ) );
		}
		if ( ! defined( 'WMSA_BASENAME' ) ) {
			define( 'WMSA_BASENAME', plugin_basename( __FILE__ ) );
		}
		if ( ! defined( 'WMSA_PLUGIN_DIR' ) ) {
			define( 'WMSA_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
	}

	public function accm_init() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
			load_plugin_textdomain( 'koala-multiple-customer-addresses', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}
	}

	public function kl_wmsa_block_init() {
		require_once WMSA_PLUGIN_DIR . '/blocks-compatibility/ka-mca-checkout-block/ka-mca-block-integration-checkout.php';

		if ( class_exists( 'Koalaaps_Multiple_Customer_Address_Checkout_Blocks_Integration' ) ) {

			add_action(
				'woocommerce_blocks_checkout_block_registration',
				function ( $integration_registry ) {
					$integration_registry->register( new Koalaaps_Multiple_Customer_Address_Checkout_Blocks_Integration() );
				}
			);
		}
	}
}
if ( class_exists( 'Ka_Customer_Addresses' ) ) {
	new Ka_Customer_Addresses();
}
